]> git.cameronkatri.com Git - mandoc.git/blobdiff - out.h
clarify the difference between .Cm and .Ic;
[mandoc.git] / out.h
diff --git a/out.h b/out.h
index 2c1cf3fe9701986b45c547155700c5a95d78c8e1..dec6a8f873247bde1fd0c446aa80f00da7069824 100644 (file)
--- a/out.h
+++ b/out.h
@@ -1,6 +1,7 @@
-/*     $Id: out.h,v 1.27 2015/11/07 14:01:16 schwarze Exp $ */
+/*     $Id: out.h,v 1.33 2018/08/18 20:18:14 schwarze Exp $ */
 /*
  * Copyright (c) 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2014, 2017, 2018 Ingo Schwarze <schwarze@openbsd.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -31,7 +32,9 @@ enum  roffscale {
 
 struct roffcol {
        size_t           width; /* width of cell */
+       size_t           nwidth; /* max. width of number in cell */
        size_t           decimal; /* decimal position in cell */
+       size_t           spacing; /* spacing after the column */
        int              flags; /* layout flags, see tbl_cell */
 };
 
@@ -40,21 +43,18 @@ struct      roffsu {
        double            scale;
 };
 
+typedef        size_t  (*tbl_sulen)(const struct roffsu *, void *);
 typedef        size_t  (*tbl_strlen)(const char *, void *);
 typedef        size_t  (*tbl_len)(size_t, void *);
 
 struct rofftbl {
+       tbl_sulen        sulen; /* calculate scaling unit length */
        tbl_strlen       slen; /* calculate string length */
        tbl_len          len; /* produce width of empty space */
        struct roffcol  *cols; /* master column specifiers */
-       void            *arg; /* passed to slen and len */
+       void            *arg; /* passed to sulen, slen, and len */
 };
 
-#define        SCALE_VS_INIT(p, v) \
-       do { (p)->unit = SCALE_VS; \
-            (p)->scale = (v); } \
-       while (/* CONSTCOND */ 0)
-
 #define        SCALE_HS_INIT(p, v) \
        do { (p)->unit = SCALE_EN; \
             (p)->scale = (v); } \
@@ -63,6 +63,6 @@ struct        rofftbl {
 
 struct tbl_span;
 
-int              a2roffsu(const char *, struct roffsu *, enum roffscale);
+const char      *a2roffsu(const char *, struct roffsu *, enum roffscale);
 void             tblcalc(struct rofftbl *tbl,
-                       const struct tbl_span *, size_t);
+                       const struct tbl_span *, size_t, size_t);